##  The Contribution of Enterprise Architects to Phase 0
Looking at the questions typically addressed during this phase, Enterprise Architects can contribute in many ways, for example,
  * Create transparency on the current landscape and well-known transformation needs due to, for example, technological changes, technical debt, and missing functional fit.
  * Share your view on (run) costs associated with platforms, applications, or IT components in scope.
  * Discuss the potential architectural impacts of the different transformation approaches.
  * Understand the impact on existing transformations and the effect on their roadmaps.


Much of the data needed to contribute to these discussions can be extracted from your SAP LeanIX solution. If any data is missing, the impending ERP transformation can provide a strong lever to escalate SAP LeanIX adoption.
